==> blesta-5.10.2.zip: blesta/language/el_gr/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getsearchoptions.packages'] = 'Αναζήτηση πακέτων';
$lang['Navigation.getsearchoptions.services'] = 'Αναζήτηση υπηρεσιών';
$lang['Navigation.getsearchoptions.transactions'] = 'Αναζήτηση συναλλαγών';
$lang['Navigation.getsearchoptions.invoices'] = 'Αναζήτηση τιμολογίων';
$lang['Navigation.getsearchoptions.clients'] = 'Αναζήτηση πελατών';
$lang['Navigation.getsearchoptions.smart'] = 'Έξυπνη αναζήτηση';
$lang['Navigation.getsystem.nav_marketplace'] = 'Αγορά';
$lang['Navigation.getsystem.nav_help_about'] = 'Σχετικά με τη Blesta';
$lang['Navigation.getsystem.nav_help_notes'] = 'Σημειώσεις έκδοσης';
$lang['Navigation.getsystem.nav_help_index'] = 'Πόροι';
$lang['Navigation.getsystem.nav_help'] = 'Βοήθεια';
$lang['Navigation.getsystem.nav_upgrade'] = 'Επιλογές αναβάθμισης';
$lang['Navigation.getsystem.nav_api'] = 'Πρόσβαση API';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Ομάδες προσωπικού';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Διαχείριση προσωπικού';
$lang['Navigation.getsystem.nav_staff'] = 'Προσωπικό';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'Κατά παραγγελία';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Ασφαλές FTP';
$lang['Navigation.getsystem.nav_backup'] = 'Δημιουργία αντιγράφων ασφαλείας';
$lang['Navigation.getsystem.nav_companies'] = 'Εταιρείες';
$lang['Navigation.getsystem.nav_automation'] = 'Αυτοματισμός';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Τύποι πληρωμών';
$lang['Navigation.getsystem.nav_general_license'] = 'Κλειδί άδειας χρήσης';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Συντήρηση';
$lang['Navigation.getsystem.nav_general_geoip'] = 'Ρυθμίσεις GeoIP';
$lang['Navigation.getsystem.nav_general_basic'] = 'Βασική ρύθμιση';
$lang['Navigation.getsystem.nav_general'] = 'Γενικά';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Ρυθμίσεις τροφοδοσίας';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Γενικά';
$lang['Navigation.getcompany.nav_feeds'] = 'Τροφοδοτήσεις δεδομένων';
$lang['Navigation.getcompany.nav_groups'] = 'Ομάδες πελατών';
$lang['Navigation.getcompany.nav_plugins'] = 'Plugins';
$lang['Navigation.getcompany.nav_currency_active'] = 'Ενεργά νομίσματα';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Ρύθμιση νομίσματος';
$lang['Navigation.getcompany.nav_currencies'] = 'Νομίσματα';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Απαιτούμενα πεδία πελάτη';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Προσαρμοσμένα πεδία πελάτη';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Γενικές ρυθμίσεις πελάτη';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Επιλογές πελάτη';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Υπογραφές';
$lang['Navigation.getcompany.nav_emails_templates'] = 'Πρότυπα email';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Ρυθμίσεις ταχυδρομείου';
$lang['Navigation.getcompany.nav_emails'] = 'Ηλεκτρονικά μηνύματα';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Φορολογικοί κανόνες';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Βασικές φορολογικές ρυθμίσεις';
$lang['Navigation.getcompany.nav_taxes'] = 'Φόροι';
$lang['Navigation.getcompany.nav_gateways'] = 'Πύλες πληρωμών';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Πρότυπα μηνυμάτων';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Διαμόρφωση Messenger';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Αγγελιοφόροι';
$lang['Navigation.getcompany.nav_messengers'] = 'Αγγελιοφόροι';
$lang['Navigation.getcompany.nav_modules'] = 'Ενότητες';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Αποδεκτοί τύποι πληρωμών';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Κουπόνια';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Ανακοινώσεις';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Τέλη καθυστέρησης';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Παράδοση τιμολογίου';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Προσαρμογή τιμολογίου';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Επιλογές τιμολόγησης και χρέωσης';
$lang['Navigation.getcompany.nav_billing'] = 'Τιμολόγηση/Πληρωμή';
$lang['Navigation.getcompany.nav_automation'] = 'Αυτοματισμός';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Προσαρμογή';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Δράσεις';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Πλοήγηση';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Διάταξη';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Πρότυπο';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Θέματα';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Εμφάνιση και αίσθηση';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Ανθρώπινη επαλήθευση';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Έξυπνη αναζήτηση';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Μάρκετινγκ';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Τύποι επικοινωνίας';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Κρυπτογράφηση';
$lang['Navigation.getcompany.nav_general_international'] = 'Διεθνοποίηση';
$lang['Navigation.getcompany.nav_general_localization'] = 'Εντοπισμός';
$lang['Navigation.getcompany.nav_general'] = 'Γενικά';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Αρχική σελίδα';
$lang['Navigation.getprimaryclient.nav_return'] = 'Επιστροφή στο ταμπλό';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Προσθήκη επαφής';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Επαφές';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Προσθήκη λογαριασμού πληρωμών';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Λογαριασμοί πληρωμών';
$lang['Navigation.getprimaryclient.nav_services'] = 'Υπηρεσίες';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Ταμπλό';
$lang['Navigation.getprimary.nav_settings_system'] = 'Σύστημα';
$lang['Navigation.getprimary.nav_settings_company'] = 'Εταιρεία';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Ουρά ανανέωσης';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Υπηρεσίες κοινής ωφέλειας';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Μετατροπή νομίσματος';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Ημερολόγια';
$lang['Navigation.getprimary.nav_tools'] = 'Εργαλεία';
$lang['Navigation.getprimary.nav_package_options'] = 'Διαμορφώσιμες επιλογές';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Ομάδες πακέτων';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Αναζήτηση πακέτων';
$lang['Navigation.getprimary.nav_packages'] = 'Πακέτα';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Παρτίδα';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Ουρά εκτύπωσης';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Αναφορές';
$lang['Navigation.getprimary.nav_billing_services'] = 'Υπηρεσίες';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Συναλλαγές';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Αποσπάσματα';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Τιμολόγια';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Επισκόπηση';
$lang['Navigation.getprimary.nav_billing'] = 'Τιμολόγηση';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Αναζήτηση πελατών';
$lang['Navigation.getprimary.nav_clients'] = 'Πελάτες';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Ταμπλό';
$lang['Navigation.getprimary.nav_home'] = 'Αρχική σελίδα';
$lang['Navigation.!error.parent_id.valid'] = 'Μη έγκυρο αναγνωριστικό στοιχείου πλοήγησης γονέα';
$lang['Navigation.!error.order.valid'] = 'Ο δείκτης παραγγελίας πρέπει να είναι αριθμητική τιμή';
$lang['Navigation.!error.action_id.valid'] = 'Μη έγκυρο αναγνωριστικό δράσης';
$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Μαύρη λίστα';

==> blesta-5.11.4.zip: blesta/language/el_gr/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getsearchoptions.packages'] = 'Αναζήτηση πακέτων';
$lang['Navigation.getsearchoptions.services'] = 'Αναζήτηση υπηρεσιών';
$lang['Navigation.getsearchoptions.transactions'] = 'Αναζήτηση συναλλαγών';
$lang['Navigation.getsearchoptions.invoices'] = 'Αναζήτηση τιμολογίων';
$lang['Navigation.getsearchoptions.clients'] = 'Αναζήτηση πελατών';
$lang['Navigation.getsearchoptions.smart'] = 'Έξυπνη αναζήτηση';
$lang['Navigation.getsystem.nav_marketplace'] = 'Αγορά';
$lang['Navigation.getsystem.nav_help_about'] = 'Σχετικά με τη Blesta';
$lang['Navigation.getsystem.nav_help_notes'] = 'Σημειώσεις έκδοσης';
$lang['Navigation.getsystem.nav_help_index'] = 'Πόροι';
$lang['Navigation.getsystem.nav_help'] = 'Βοήθεια';
$lang['Navigation.getsystem.nav_upgrade'] = 'Επιλογές αναβάθμισης';
$lang['Navigation.getsystem.nav_api'] = 'Πρόσβαση API';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Ομάδες προσωπικού';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Διαχείριση προσωπικού';
$lang['Navigation.getsystem.nav_staff'] = 'Προσωπικό';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'Κατά παραγγελία';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Ασφαλές FTP';
$lang['Navigation.getsystem.nav_backup'] = 'Δημιουργία αντιγράφων ασφαλείας';
$lang['Navigation.getsystem.nav_companies'] = 'Εταιρείες';
$lang['Navigation.getsystem.nav_automation'] = 'Αυτοματισμός';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Τύποι πληρωμών';
$lang['Navigation.getsystem.nav_general_license'] = 'Κλειδί άδειας χρήσης';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Συντήρηση';
$lang['Navigation.getsystem.nav_general_geoip'] = 'Ρυθμίσεις GeoIP';
$lang['Navigation.getsystem.nav_general_basic'] = 'Βασική ρύθμιση';
$lang['Navigation.getsystem.nav_general'] = 'Γενικά';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Ρυθμίσεις τροφοδοσίας';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Γενικά';
$lang['Navigation.getcompany.nav_feeds'] = 'Τροφοδοτήσεις δεδομένων';
$lang['Navigation.getcompany.nav_groups'] = 'Ομάδες πελατών';
$lang['Navigation.getcompany.nav_plugins'] = 'Plugins';
$lang['Navigation.getcompany.nav_currency_active'] = 'Ενεργά νομίσματα';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Ρύθμιση νομίσματος';
$lang['Navigation.getcompany.nav_currencies'] = 'Νομίσματα';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Απαιτούμενα πεδία πελάτη';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Προσαρμοσμένα πεδία πελάτη';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Γενικές ρυθμίσεις πελάτη';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Επιλογές πελάτη';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Υπογραφές';
$lang['Navigation.getcompany.nav_emails_templates'] = 'Πρότυπα email';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Ρυθμίσεις ταχυδρομείου';
$lang['Navigation.getcompany.nav_emails'] = 'Ηλεκτρονικά μηνύματα';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Φορολογικοί κανόνες';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Βασικές φορολογικές ρυθμίσεις';
$lang['Navigation.getcompany.nav_taxes'] = 'Φόροι';
$lang['Navigation.getcompany.nav_gateways'] = 'Πύλες πληρωμών';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Πρότυπα μηνυμάτων';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Διαμόρφωση Messenger';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Αγγελιοφόροι';
$lang['Navigation.getcompany.nav_messengers'] = 'Αγγελιοφόροι';
$lang['Navigation.getcompany.nav_modules'] = 'Ενότητες';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Αποδεκτοί τύποι πληρωμών';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Κουπόνια';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Ανακοινώσεις';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Τέλη καθυστέρησης';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Παράδοση τιμολογίου';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Προσαρμογή τιμολογίου';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Επιλογές τιμολόγησης και χρέωσης';
$lang['Navigation.getcompany.nav_billing'] = 'Τιμολόγηση/Πληρωμή';
$lang['Navigation.getcompany.nav_automation'] = 'Αυτοματισμός';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Προσαρμογή';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Δράσεις';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Πλοήγηση';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Διάταξη';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Πρότυπο';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Θέματα';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Εμφάνιση και αίσθηση';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Ανθρώπινη επαλήθευση';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Έξυπνη αναζήτηση';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Μάρκετινγκ';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Τύποι επικοινωνίας';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Κρυπτογράφηση';
$lang['Navigation.getcompany.nav_general_international'] = 'Διεθνοποίηση';
$lang['Navigation.getcompany.nav_general_localization'] = 'Εντοπισμός';
$lang['Navigation.getcompany.nav_general'] = 'Γενικά';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Αρχική σελίδα';
$lang['Navigation.getprimaryclient.nav_return'] = 'Επιστροφή στο ταμπλό';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Προσθήκη επαφής';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Επαφές';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Προσθήκη λογαριασμού πληρωμών';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Λογαριασμοί πληρωμών';
$lang['Navigation.getprimaryclient.nav_services'] = 'Υπηρεσίες';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Ταμπλό';
$lang['Navigation.getprimary.nav_settings_system'] = 'Σύστημα';
$lang['Navigation.getprimary.nav_settings_company'] = 'Εταιρεία';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Ουρά ανανέωσης';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Υπηρεσίες κοινής ωφέλειας';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Μετατροπή νομίσματος';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Ημερολόγια';
$lang['Navigation.getprimary.nav_tools'] = 'Εργαλεία';
$lang['Navigation.getprimary.nav_package_options'] = 'Διαμορφώσιμες επιλογές';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Ομάδες πακέτων';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Αναζήτηση πακέτων';
$lang['Navigation.getprimary.nav_packages'] = 'Πακέτα';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Παρτίδα';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Ουρά εκτύπωσης';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Αναφορές';
$lang['Navigation.getprimary.nav_billing_services'] = 'Υπηρεσίες';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Συναλλαγές';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Αποσπάσματα';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Τιμολόγια';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Επισκόπηση';
$lang['Navigation.getprimary.nav_billing'] = 'Τιμολόγηση';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Αναζήτηση πελατών';
$lang['Navigation.getprimary.nav_clients'] = 'Πελάτες';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Ταμπλό';
$lang['Navigation.getprimary.nav_home'] = 'Αρχική σελίδα';
$lang['Navigation.!error.parent_id.valid'] = 'Μη έγκυρο αναγνωριστικό στοιχείου πλοήγησης γονέα';
$lang['Navigation.!error.order.valid'] = 'Ο δείκτης παραγγελίας πρέπει να είναι αριθμητική τιμή';
$lang['Navigation.!error.action_id.valid'] = 'Μη έγκυρο αναγνωριστικό δράσης';
$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Μαύρη λίστα';
$lang['Navigation.getcompany.nav_html_templates'] = 'Πρότυπα HTML';
$lang['Navigation.getprimary.nav_tools_provisioning'] = 'Ουρά εξυπηρέτησης';
